==> flutter_upchunk-0.1.2.tar.gz: lib/src/connection_status_singleton.dart <==
import 'dart:async';
import 'dart:io';

import 'package:connectivity/connectivity.dart';

class ConnectionStatusSingleton {
  //This creates the single instance by calling the `_internal` constructor specified below
  static final ConnectionStatusSingleton _singleton = new ConnectionStatusSingleton._internal();
  ConnectionStatusSingleton._internal();

  //This is what's used to retrieve the instance through the app
  static ConnectionStatusSingleton getInstance() => _singleton;

  //This tracks the current connection status
  bool hasConnection = false;

  //This is how we'll allow subscribing to connection changes
  StreamController connectionChangeController = new StreamController.broadcast();

  //flutter_connectivity
  final Connectivity _connectivity = Connectivity();

  bool _initialized;

  //Hook into flutter_connectivity's Stream to listen for changes
  //And check the connection status out of the gate
  void initialize() {
    if (_initialized) return;

    _connectivity.onConnectivityChanged.listen(_connectionChange);
    checkConnection();

    _initialized = true;
  }

  Stream get connectionChange => connectionChangeController.stream;

  //A clean up method to close our StreamController
  //   Because this is meant to exist through the entire application life cycle this isn't
  //   really an issue
  void dispose() {
    connectionChangeController.close();
  }

  //flutter_connectivity's listener
  void _connectionChange(ConnectivityResult result) {
    checkConnection();
  }

  //The test to actually see if there is a connection
  Future<bool> checkConnection() async {
    bool previousConnection = hasConnection;

    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        hasConnection = true;
      } else {
        hasConnection = false;
      }
    } on SocketException catch(_) {
      hasConnection = false;
    }

    //The connection status changed send out an update to all listeners
    if (previousConnection != hasConnection) {
      connectionChangeController.add(hasConnection);
    }

    return hasConnection;
  }
}

==> flutter_upchunk-0.1.5.tar.gz: lib/src/connection_status_singleton.dart <==
import 'dart:async';
import 'dart:io';

import 'package:connectivity/connectivity.dart';

class ConnectionStatusSingleton {
  /// Creates the single instance by calling the `_internal` constructor specified below
  static final ConnectionStatusSingleton _singleton = new ConnectionStatusSingleton._internal();
  ConnectionStatusSingleton._internal();

  /// Retrieves the singleton instance
  static ConnectionStatusSingleton getInstance() => _singleton;

  /// Tracks the current connection status
  bool hasConnection = false;

  /// Allows subscribing to connection changes
  StreamController connectionChangeController = new StreamController.broadcast();

  /// flutter_connectivity object
  final Connectivity _connectivity = Connectivity();

  bool _initialized;

  /// Hooks into [_connectivity]'s Stream to listen for changes
  /// and checks the connection status out of the gate
  void initialize() {
    if (_initialized) return;

    _connectivity.onConnectivityChanged.listen(_connectionChange);
    checkConnection();

    _initialized = true;
  }

  Stream get connectionChange => connectionChangeController.stream;

  /// A clean up method to close our StreamController
  void dispose() {
    connectionChangeController.close();
  }

  /// [_connectivity]'s listener
  void _connectionChange(ConnectivityResult result) {
    checkConnection();
  }

  /// Tests to verify if there's indeed connected to the internet
  Future<bool> checkConnection() async {
    bool previousConnection = hasConnection;

    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        hasConnection = true;
      } else {
        hasConnection = false;
      }
    } on SocketException catch(_) {
      hasConnection = false;
    }

    //The connection status changed send out an update to all listeners
    if (previousConnection != hasConnection) {
      connectionChangeController.add(hasConnection);
    }

    return hasConnection;
  }
}
